# Advanced: custom window operations

:::jaxscape.utils.padding

::: jaxscape.window_operation.WindowOperation
    options:
      members: 
        - nb_steps
        - extract_total_window
        - extract_core_window
        - update_raster_with_core_window
        - update_raster_with_window
        - lazy_iterator
        - eager_iterator

::: jaxscape.windowed_analysis.WindowedAnalysis
    options:
      members: false